@@ -8,7 +8,6 @@ from ..models.actor_response_body import ActorResponseBody
 from ..models.custom_field_entry_response_body import CustomFieldEntryResponseBody
 from ..models.incident_response_body_mode import IncidentResponseBodyMode
 from ..models.incident_response_body_status import IncidentResponseBodyStatus
-from ..models.incident_response_body_type import IncidentResponseBodyType
 from ..models.incident_response_body_visibility import IncidentResponseBodyVisibility
 from ..models.incident_role_assignment_response_body import (
     IncidentRoleAssignmentResponseBody,
@@ -48,47 +47,32 @@ class IncidentResponseBody:
             'value_text': 'This is my text field, I hope you like it'}, {'value_link': 'https://google.com/',
             'value_numeric': '123.456', 'value_option': {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id':
             '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'}, 'value_text': 'This is my text field, I hope
-            you like it'}]}, {'custom_field': {'description': 'Which team is impacted by this issue', 'field_type':
-            'single_select', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Affected Team', 'options': [{'custom_field_id':
-            '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'},
-            {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value':
-            'Product'}, {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key':
-            10, 'value': 'Product'}]}, 'values': [{'value_link': 'https://google.com/', 'value_numeric': '123.456',
-            'value_option': {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'sort_key': 10, 'value': 'Product'}, 'value_text': 'This is my text field, I hope you like it'}, {'value_link':
-            'https://google.com/', 'value_numeric': '123.456', 'value_option': {'custom_field_id':
-            '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'},
-            'value_text': 'This is my text field, I hope you like it'}]}], 'id': '01FDAG4SAP5TYPT98WGR2N7W91',
-            'incident_role_assignments': [{'assignee': {'email': 'lisa@incident.io', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at': '2021-08-17T13:28:57.801578Z',
-            'description': 'The person currently coordinating the incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'instructions': 'Take point on the incident; Make sure people are clear on responsibilities', 'name': 'Incident
-            Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead', 'updated_at':
-            '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'email': 'lisa@incident.io', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at': '2021-08-17T13:28:57.801578Z',
-            'description': 'The person currently coordinating the incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'instructions': 'Take point on the incident; Make sure people are clear on responsibilities', 'name': 'Incident
-            Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead', 'updated_at':
-            '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'email': 'lisa@incident.io', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at': '2021-08-17T13:28:57.801578Z',
-            'description': 'The person currently coordinating the incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'instructions': 'Take point on the incident; Make sure people are clear on responsibilities', 'name': 'Incident
-            Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead', 'updated_at':
-            '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'email': 'lisa@incident.io', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at': '2021-08-17T13:28:57.801578Z',
-            'description': 'The person currently coordinating the incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'instructions': 'Take point on the incident; Make sure people are clear on responsibilities', 'name': 'Incident
-            Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead', 'updated_at':
-            '2021-08-17T13:28:57.801578Z'}}], 'mode': 'real', 'name': 'Our database is sad', 'permalink': 'Alias aut rerum
-            fugiat exercitationem maiores.', 'postmortem_document_url': 'https://docs.google.com/my_doc_id', 'reference':
-            'INC-123', 'severity': {'created_at': '2021-08-17T13:28:57.801578Z', 'description': "It's not really that bad,
-            everyone chill", 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Minor', 'rank': 1, 'updated_at':
+            you like it'}]}], 'id': '01FDAG4SAP5TYPT98WGR2N7W91', 'incident_role_assignments': [{'assignee': {'email':
+            'lisa@incident.io', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role':
+            {'created_at': '2021-08-17T13:28:57.801578Z', 'description': 'The person currently coordinating the incident',
+            'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident; Make sure people are clear on
+            responsibilities', 'name': 'Incident Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead',
+            'updated_at': '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'email': 'lisa@incident.io', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at':
+            '2021-08-17T13:28:57.801578Z', 'description': 'The person currently coordinating the incident', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident; Make sure people are clear on
+            responsibilities', 'name': 'Incident Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead',
+            'updated_at': '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'email': 'lisa@incident.io', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at':
+            '2021-08-17T13:28:57.801578Z', 'description': 'The person currently coordinating the incident', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident; Make sure people are clear on
+            responsibilities', 'name': 'Incident Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead',
+            'updated_at': '2021-08-17T13:28:57.801578Z'}}], 'mode': 'real', 'name': 'Our database is sad', 'permalink':
+            'Ratione est.', 'postmortem_document_url': 'https://docs.google.com/my_doc_id', 'reference': 'INC-123',
+            'severity': {'created_at': '2021-08-17T13:28:57.801578Z', 'description': "It's not really that bad, everyone
+            chill", 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Minor', 'rank': 1, 'updated_at':
             '2021-08-17T13:28:57.801578Z'}, 'slack_channel_id': 'C02AW36C1M5', 'slack_channel_name': 'inc-165-green-parrot',
             'status': 'triage', 'summary': "Our database is really really sad, and we don't know why yet.", 'timestamps':
             [{'last_occurred_at': '2021-08-17T13:28:57.801578Z', 'name': 'last_activity'}, {'last_occurred_at':
             '2021-08-17T13:28:57.801578Z', 'name': 'last_activity'}, {'last_occurred_at': '2021-08-17T13:28:57.801578Z',
             'name': 'last_activity'}, {'last_occurred_at': '2021-08-17T13:28:57.801578Z', 'name': 'last_activity'}], 'type':
-            'real', 'updated_at': '2021-08-17T13:28:57.801578Z', 'visibility': 'public'}
+            'Expedita aliquam eligendi cupiditate voluptatem distinctio ut.', 'updated_at': '2021-08-17T13:28:57.801578Z',
+            'visibility': 'public'}
 
     Attributes:
         created_at (datetime.datetime): When the incident was created Example: 2021-08-17T13:28:57.801578Z.
@@ -127,7 +111,18 @@ class IncidentResponseBody:
             'sort_key': 10, 'value': 'Product'}, 'value_text': 'This is my text field, I hope you like it'}, {'value_link':
             'https://google.com/', 'value_numeric': '123.456', 'value_option': {'custom_field_id':
             '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'},
-            'value_text': 'This is my text field, I hope you like it'}]}].
+            'value_text': 'This is my text field, I hope you like it'}]}, {'custom_field': {'description': 'Which team is
+            impacted by this issue', 'field_type': 'single_select', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Affected
+            Team', 'options': [{'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
+            'sort_key': 10, 'value': 'Product'}, {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'}, {'custom_field_id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'}]},
+            'values': [{'value_link': 'https://google.com/', 'value_numeric': '123.456', 'value_option': {'custom_field_id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'},
+            'value_text': 'This is my text field, I hope you like it'}, {'value_link': 'https://google.com/',
+            'value_numeric': '123.456', 'value_option': {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'}, 'value_text': 'This is my text field, I hope
+            you like it'}]}].
         id (str): Unique identifier for the incident Example: 01FDAG4SAP5TYPT98WGR2N7W91.
         incident_role_assignments (List[IncidentRoleAssignmentResponseBody]): A list of who is assigned to each role for
             this incident Example: [{'assignee': {'email': 'lisa@incident.io', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name':
@@ -158,12 +153,10 @@ class IncidentResponseBody:
             'updated_at': '2021-08-17T13:28:57.801578Z'}.
         slack_channel_id (str): ID of the Slack channel in the organisation Slack workspace Example: C02AW36C1M5.
         status (IncidentResponseBodyStatus): Current status of the incident Example: triage.
-        type (IncidentResponseBodyType): DEPRECATED: please use mode instead. Whether the incident is real, a test, or a
-            tutorial Example: real.
         updated_at (datetime.datetime): When the incident was last updated Example: 2021-08-17T13:28:57.801578Z.
         visibility (IncidentResponseBodyVisibility): Whether the incident is public or private Example: public.
         call_url (Union[Unset, str]): The call URL attached to this incident Example: https://zoom.us/foo.
-        permalink (Union[Unset, str]):  Example: Officia dolore autem ea et..
+        permalink (Union[Unset, str]):  Example: Et amet non sed sit quia..
         postmortem_document_url (Union[Unset, str]): Description of the incident Example:
             https://docs.google.com/my_doc_id.
         slack_channel_name (Union[Unset, str]): Name of the slack channel Example: inc-165-green-parrot.
@@ -174,6 +167,7 @@ class IncidentResponseBody:
             {'last_occurred_at': '2021-08-17T13:28:57.801578Z', 'name': 'last_activity'}, {'last_occurred_at':
             '2021-08-17T13:28:57.801578Z', 'name': 'last_activity'}, {'last_occurred_at': '2021-08-17T13:28:57.801578Z',
             'name': 'last_activity'}].
+        type (Union[Unset, str]):  Example: Atque dignissimos accusamus explicabo..
     """
 
     created_at: datetime.datetime
@@ -187,7 +181,6 @@ class IncidentResponseBody:
     severity: SeverityResponseBody
     slack_channel_id: str
     status: IncidentResponseBodyStatus
-    type: IncidentResponseBodyType
     updated_at: datetime.datetime
     visibility: IncidentResponseBodyVisibility
     call_url: Union[Unset, str] = UNSET
@@ -196,6 +189,7 @@ class IncidentResponseBody:
     slack_channel_name: Union[Unset, str] = UNSET
     summary: Union[Unset, str] = UNSET
     timestamps: Union[Unset, List[IncidentTimestampResponseBody]] = UNSET
+    type: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -225,8 +219,6 @@ class IncidentResponseBody:
         slack_channel_id = self.slack_channel_id
         status = self.status.value
 
-        type = self.type.value
-
         updated_at = self.updated_at.isoformat()
 
         visibility = self.visibility.value
@@ -244,6 +236,8 @@ class IncidentResponseBody:
 
                 timestamps.append(timestamps_item)
 
+        type = self.type
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -259,7 +253,6 @@ class IncidentResponseBody:
                 "severity": severity,
                 "slack_channel_id": slack_channel_id,
                 "status": status,
-                "type": type,
                 "updated_at": updated_at,
                 "visibility": visibility,
             }
@@ -276,6 +269,8 @@ class IncidentResponseBody:
             field_dict["summary"] = summary
         if timestamps is not UNSET:
             field_dict["timestamps"] = timestamps
+        if type is not UNSET:
+            field_dict["type"] = type
 
         return field_dict
 
@@ -318,8 +313,6 @@ class IncidentResponseBody:
 
         status = IncidentResponseBodyStatus(d.pop("status"))
 
-        type = IncidentResponseBodyType(d.pop("type"))
-
         updated_at = isoparse(d.pop("updated_at"))
 
         visibility = IncidentResponseBodyVisibility(d.pop("visibility"))
@@ -341,6 +334,8 @@ class IncidentResponseBody:
 
             timestamps.append(timestamps_item)
 
+        type = d.pop("type", UNSET)
+
         incident_response_body = cls(
             created_at=created_at,
             creator=creator,
@@ -353,7 +348,6 @@ class IncidentResponseBody:
             severity=severity,
             slack_channel_id=slack_channel_id,
             status=status,
-            type=type,
             updated_at=updated_at,
             visibility=visibility,
             call_url=call_url,
@@ -362,6 +356,7 @@ class IncidentResponseBody:
             slack_channel_name=slack_channel_name,
             summary=summary,
             timestamps=timestamps,
+            type=type,
         )
 
         incident_response_body.additional_properties = d
